import { DragModal, DragModalTitle, getComputedHeight } from '@/components/a/drag-modal/index.tsx';
import { useChatStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { ChatCopyList } from './List';

export const ChatCopyDialog = () => {
  const store = useChatStore(
    useShallow((state) => ({
      showCopy: state.showCopy,
      setShowCopy: state.setShowCopy,
      setModelId: state.setModelId,
      modelId: state.modelId,
    })),
  );
  const computedHeight = getComputedHeight();
  if (!store.showCopy) {
    return null;
  }
  return (
    <DragModal
      focus={store.modelId === 'chat-copy'}
      title={
        <DragModalTitle
          title='Chat Copy'
          onClose={() => store.setShowCopy(false)}
          onClick={() => {
            store.setModelId('chat-copy');
          }}
        />
      }
      content={
        <div className='w-full h-full p-2 overflow-y-auto scrollbar'>
          <ChatCopyList />
        </div>
      }
      defaultSize={{
        width: 600,
        height: 400,
      }}
      style={{
        left: computedHeight.width / 2 - 300,
        top: computedHeight.height / 2 - 200,
      }}
    />
  );
};
