import { useChatStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { IconButton } from '@/components/a/button.tsx'
import { CircleCheckBig, Edit, LassoSelectIcon } from 'lucide-react';
import clsx from 'clsx';
import { Tooltip } from '@/components/a/tooltip.tsx'

export const ChatSettingList = () => {
  const { currentUserModel, setCurrentUserModel, modelList, showChatSetting, setShowChatSetting } = useChatStore(
    useShallow((state) => ({
      currentUserModel: state.currentUserModel,
      setCurrentUserModel: state.setCurrentUserModel,
      modelList: state.modelList,
      showChatSetting: state.showChatSetting,
      setShowChatSetting: state.setShowChatSetting,
    })),
  );
 
  return (
    <div className='w-full h-full p-2'>
      {modelList?.map?.((model, index) => {
        const selectOpts = model.selectOpts || ([] as { group: string; provider: string; model: string }[]);
        const isCurrentUserModel = currentUserModel?.username === model.username;
        const isLastModel = index === modelList.length - 1;
        return (
          <div key={index} className={clsx('border-b-gray-200 border-b pb-2', isLastModel ? 'border-b-0' : '')}>
            <div className='text-lg font-bold capitalize'>
              <Tooltip title={`使用用户: ${model.username} 的对话模型`}>
                <div className='cursor-pointer'>user: {model.username}</div>
              </Tooltip>
            </div>
            {selectOpts.map((opt, index) => {
              const isLast = index === selectOpts.length - 1;
              const isSelected = isCurrentUserModel && currentUserModel?.model?.group === opt.group && currentUserModel?.model?.model === opt.model;
              return (
                <div
                  key={'select-opt-' + index}
                  className={clsx('border-b-gray-200 p-2 flex justify-between', isLast ? 'border-b-0' : 'border-b', isSelected ? 'bg-gray-100' : '')}>
                  <div>
                    <div>group: {opt.group}</div>
                    <div>provider: {opt.provider}</div>
                    <div>model: {opt.model}</div>
                    {opt.description && <div>{opt.description}</div>}
                  </div>
                  <div className=' gap-2'>
                    <Tooltip title='设置为当前模型'>
                      <IconButton
                        onClick={() => {
                          setCurrentUserModel({
                            username: model.username,
                            model: opt,
                          });
                          setShowChatSetting(false);
                        }}>
                        <CircleCheckBig className='w-4 h-4' />
                      </IconButton>
                    </Tooltip>
                  </div>
                </div>
              );
            })}
          </div>
        );
      })}
    </div>
  );
};
