import { DragModal, DragModalTitle, getComputedHeight } from '@/components/a/drag-modal/index.tsx';
import { useChatStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { ChatSettingList } from './List';

export const ChatSettingDialog = () => {
  const { showSetting, setShowSetting, setModelId, modelId } = useChatStore(
    useShallow((state) => ({
      showSetting: state.showSetting,
      setShowSetting: state.setShowSetting,
      setModelId: state.setModelId,
      modelId: state.modelId,
    })),
  );
  const computedHeight = getComputedHeight();
  if (!showSetting) {
    return null;
  }
  return (
    <DragModal
      focus={modelId === 'chat-setting'}
      title={
        <DragModalTitle
          title='Chat Setting'
          onClose={() => setShowSetting(false)}
          onClick={() => {
            setModelId('chat-setting');
          }}
        />
      }
      content={
        <div className='w-full h-full p-2 overflow-y-auto scrollbar'>
          <ChatSettingList />
        </div>
      }
      defaultSize={{
        width: 600,
        height: 400,
      }}
      style={{
        left: computedHeight.width / 2 - 300,
        top: computedHeight.height / 2 - 200,
      }}
    />
  );
};
