import { throttle } from 'lodash-es';
import { Marked } from 'marked';
import 'highlight.js/styles/github.css'; // 你可以选择其他样式
import { useRef, useEffect } from 'react';

import { markedHighlight } from 'marked-highlight';
import hljs from 'highlight.js';
import clsx from 'clsx';

const marked = new Marked(
  markedHighlight({
    emptyLangClass: 'hljs',
    langPrefix: 'hljs language-',
    highlight(code, lang, info) {
      const language = hljs.getLanguage(lang) ? lang : 'plaintext';
      return hljs.highlight(code, { language }).value;
    },
  }),
);

type ResponseTextProps = {
  response: Response;
  onFinish?: (text: string) => void;
  onChange?: (text: string) => void;
  className?: string;
  id?: string;
};
export const ResponseText = (props: ResponseTextProps) => {
  const ref = useRef<HTMLDivElement>(null);
  const render = async () => {
    const response = props.response;
    if (!response) return;
    const msg = ref.current!;
    if (!msg) {
      console.log('msg is null');
      return;
    }
    await new Promise((resolve) => setTimeout(resolve, 100));
    const reader = response.body?.getReader();
    const decoder = new TextDecoder('utf-8');
    let done = false;

    while (!done) {
      const { value, done: streamDone } = await reader!.read();
      done = streamDone;

      if (value) {
        const chunk = decoder.decode(value, { stream: true });
        // 更新状态，实时刷新 UI
        msg.innerHTML += chunk;
      }
    }
    if (done) {
      props.onFinish && props.onFinish(msg.innerHTML);
    }
  };
  useEffect(() => {
    render();
  }, []);
  return <div id={props.id} className={clsx('response markdown-body', props.className)} ref={ref}></div>;
};

export const ResponseMarkdown = (props: ResponseTextProps) => {
  const ref = useRef<HTMLDivElement>(null);
  let content = '';
  const render = async () => {
    const response = props.response;
    if (!response) return;
    const msg = ref.current!;
    if (!msg) {
      console.log('msg is null');
      return;
    }
    await new Promise((resolve) => setTimeout(resolve, 100));
    const reader = response.body?.getReader();
    const decoder = new TextDecoder('utf-8');
    let done = false;

    while (!done) {
      const { value, done: streamDone } = await reader!.read();
      done = streamDone;

      if (value) {
        const chunk = decoder.decode(value, { stream: true });
        content = content + chunk;
        renderThrottle(content);
      }
    }
    if (done) {
      props.onFinish && props.onFinish(msg.innerHTML);
    }
  };
  const renderThrottle = throttle(async (markdown: string) => {
    const msg = ref.current!;
    msg.innerHTML = await marked.parse(markdown);
    props.onChange?.(msg.innerHTML);
  }, 100);
  useEffect(() => {
    render();
  }, [props.response]);
  return <div id={props.id} className={clsx('response markdown-body', props.className)} ref={ref}></div>;
};

export const Markdown = (props: { className?: string; markdown: string; id?: string }) => {
  const ref = useRef<HTMLDivElement>(null);
  const parse = async () => {
    const md = await marked.parse(props.markdown);
    const msg = ref.current!;
    msg.innerHTML = md;
  };
  useEffect(() => {
    parse();
  }, []);
  return <div id={props.id} ref={ref} className={clsx('markdown-body', props.className)}></div>;
};
