import { StoreContextProvider, useStore } from '@kevisual/store/react';
import { useShallow } from 'zustand/shallow';
import { createChatStore, useChatStore } from './store';
import { Messages } from './modules/MessageList';
import { useEffect, useLayoutEffect } from 'react';
import { ModelNav } from './modules/ModelNav';
import { Menu } from 'lucide-react';
import { IconButton } from '@/components/a/button.tsx';
import { ChatHistoryDialog } from './chat-history/Dialog';
import { getHistoryState } from '@kevisual/store/web-page.js';
import { ChatContextDialog } from './chat-context/Dialog';
import { ChatModelSettingDialog } from './chat-model-setting/Dialog';
import { ChatSettingDialog } from './chat-setting/Dialog';
import { ChatCopyDialog } from './chat-copy/Dialog';
import { ToastProvider } from '@/modules/toast/Provider';
import clsx from 'clsx';
import { ChatHistoryList } from './chat-history/List';
import './index.css';

type AppProps = {
  storeId?: string;
};
export const App = (props: AppProps) => {
  const storeId = props.storeId || 'ai-chat-store';
  useLayoutEffect(() => {
    // const token = localStorage.getItem('token');
    // if (!token) {
    //   toastLogin();
    // }
  }, []);
  return (
    <ToastProvider>
      <StoreContextProvider id={storeId} stateCreator={createChatStore}>
        <Chat storeId={storeId} />
      </StoreContextProvider>
    </ToastProvider>
  );
};

export const Chat = ({ storeId }: { storeId: string }) => {
  const { id, init, messages, showList, setShowList, setId, getChatList, chatData } = useChatStore(
    useShallow((state) => {
      return {
        id: state.id,
        init: state.init,
        messages: state.messages,
        showList: state.showList,
        setShowList: state.setShowList,
        setId: state.setId,
        getChatList: state.getChatList,
        chatData: state.chatData,
      };
    }),
  );
  useEffect(() => {
    if (showList) {
      getChatList();
    }
  }, [showList]);
  useEffect(() => {
    init(id);
  }, [id]);
  useEffect(() => {
    const chat = getHistoryState()[storeId];
    const chatId = chat?.chatId;
    const url = new URL(window.location.href);
    const urlChatId = url.searchParams.get('chatId');
    if (chatId) {
      setId(chatId);
    } else if (urlChatId) {
      setId(urlChatId);
    } else {
      getChatList();
    }
  }, []);

  return (
    <div className='w-full h-full relative'>
      {!id && (
        <div className='w-full h-full flex flex-col justify-center items-center'>
          <ChatHistoryList storeId={storeId} />
        </div>
      )}
      <div className={clsx('w-full h-full flex flex-col  ', !id && 'hidden')}>
        <IconButton
          className='absolute top-2 left-2 w-8 h-8'
          style={{
            position: 'absolute',
          }}
          onClick={() => setShowList(!showList)}>
          <Menu className='w-4 h-4' />
        </IconButton>

        <div className='h-[56px] flex justify-between items-center px-6 w-full lg:w-[80%] mx-auto'>
          <ModelNav />
        </div>
        <div
          className='relative overflow-auto scrollbar border border-gray-200 rounded shadow-sm mb-2 px-6 py-2 w-full lg:w-[80%] mx-auto'
          style={{
            height: 'calc(100% - 56px)',
          }}>
          <div className='mt-2 mb-5 min-h-[40px] relative'>
            <div className='text-sm text-gray-500 border-b border-gray-200 pb-2 truncate'>{chatData?.title}</div>
            <Messages messages={messages} />
          </div>
        </div>
      </div>
      <ChatContextDialog />
      <ChatHistoryDialog storeId={storeId} />
      <ChatModelSettingDialog />
      <ChatSettingDialog />
      <ChatCopyDialog />
    </div>
  );
};
