import { Copy, Eye, EyeOff, Menu, Plus, Save, Send, Settings, Trash } from 'lucide-react';
import { useChatStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { IconButton } from '@/components/a/button.tsx';
import { Tooltip } from '@/components/a/tooltip.tsx';
import { Divider } from '@/components/a/divider';

export const ModelNav = () => {
  const {
    id,
    messages,
    showAllContext,
    setShowAllContext,
    setShowContext,
    setContextMessage,
    updateChat,
    currentUserModel,
    setShowChatSetting,
    chat,
    setShowSetting,
    setShowCopy,
  } = useChatStore(
    useShallow((state) => {
      return {
        id: state.id,
        messages: state.messages,
        showAllContext: state.showAllContext,
        setShowAllContext: state.setShowAllContext,
        showContext: state.showContext,
        setShowContext: state.setShowContext,
        setContextMessage: state.setContextMessage,
        updateChat: state.updateChat,
        currentUserModel: state.currentUserModel,
        setShowChatSetting: state.setShowChatSetting,
        chat: state.chat,
        setShowSetting: state.setShowSetting,
        setShowCopy: state.setShowCopy,
      };
    }),
  );
  return (
    <div className='flex gap-2 items-center'>
      <div className='hidden lg:block font-bold text-gray-600'>提示词规划器</div>
      <div className='flex gap-2 items-center' onClick={() => setShowChatSetting(true)}>
        {currentUserModel && (
          <Tooltip
            title={
              <div className='p-2'>
                使用 [ {currentUserModel.username} ] 用户的对话模型
                <br /> Group: {currentUserModel.model?.group}
                <br /> Provider: {currentUserModel.model?.provider}
                <br /> Model: {currentUserModel.model?.model}
              </div>
            }>
            <div className='flex gap-2 items-center border border-gray-300 rounded-md p-2 max-w-[200px]  cursor-pointer'>
              <div className='truncate'>{currentUserModel.model?.model}</div>
            </div>
          </Tooltip>
        )}
        {!currentUserModel && <div className='text-sm text-gray-500 cursor-pointer'>Not Selected Model</div>}
      </div>
      <div className='flex gap-2 items-center'>
        {/* <Tooltip title='设置'>
          <IconButton
            onClick={() => {
              setShowSetting(true);
            }}>
            <Settings className='w-4 h-4' />
          </IconButton>
        </Tooltip> */}
        <Tooltip title={showAllContext ? '显示所有内容' : '不显示隐藏的内容'}>
          <IconButton onClick={() => setShowAllContext(!showAllContext)}>
            {showAllContext ? <Eye className='w-4 h-4' /> : <EyeOff className='w-4 h-4' />}
          </IconButton>
        </Tooltip>
        <Tooltip title='复制上下文'>
          <IconButton
            onClick={() => {
              setShowCopy(true);
            }}>
            <Copy className='w-4 h-4' />
          </IconButton>
        </Tooltip>
        <Tooltip title='添加上下文'>
          <IconButton
            onClick={() => {
              setContextMessage(undefined);
              setShowContext(true);
            }}>
            <Plus className='w-4 h-4' />
          </IconButton>
        </Tooltip>
        <Divider orientation='vertical' />
        <Tooltip title='保存, 默认只在本地编辑，请手动保存。'>
          <IconButton
            onClick={() => {
              updateChat({
                id: id,
                data: {
                  messages: messages,
                },
              });
            }}>
            <Save className='w-4 h-4' />
          </IconButton>
        </Tooltip>
        <Tooltip title='发送请求。'>
          <IconButton
            onClick={() => {
              chat();
            }}>
            <Send className='w-4 h-4' />
          </IconButton>
        </Tooltip>
      </div>
    </div>
  );
};
