import { useChatStore } from '@/apps/ai-chat/store';
import { MessageProps } from '../MessageList';
import { Edit, EyeOff, Eye, Trash, MonitorOff, Monitor, Copy } from 'lucide-react';
import { useShallow } from 'zustand/shallow';
import { ChastHistoryMessage } from '@/apps/ai-chat/store/type';
import clsx from 'clsx';
import { Tooltip } from '@/components/a/tooltip';
import { copyText } from '@/apps/ai-chat/utils/copy';
import { Confirm } from '@/components/a/confirm';
type ActionsProps = { data: ChastHistoryMessage };
export const Actions = (props: ActionsProps) => {
  const { data } = props;

  const { deleteMessage, updateMessage, setContextMessage, contextMessage, setShowContext } = useChatStore(
    useShallow((state) => {
      return {
        deleteMessage: state.deleteMessage,
        updateMessage: state.updateMessage,
        setContextMessage: state.setContextMessage,
        contextMessage: state.contextMessage,
        setShowContext: state.setShowContext,
      };
    }),
  );
  const onEyeChange = () => {
    const newData = { ...data, hide: !data.hide };
    updateMessage(newData);
  };
  const onDelete = () => {
    data.id && deleteMessage(data.id);
  };
  const onNoUseChange = () => {
    const newData = { ...data, noUse: !data.noUse };
    updateMessage(newData);
  };
  const isEyeHide = data.hide;
  const isNoUse = data.noUse;
  const EyeIcon = isEyeHide ? Eye : EyeOff;
  const MonitorIcon = isNoUse ? Monitor : MonitorOff;
  return (
    <div className={clsx('flex gap-4 py-2 mt-1 px-2')}>
      <Tooltip title='编辑'>
        <Edit
          className='w-4 h-4 cursor-pointer hover:text-primary'
          onClick={() => {
            setContextMessage(data);
            setShowContext(true);
          }}
        />
      </Tooltip>
      <Tooltip title='复制'>
        <Copy className='w-4 h-4 cursor-pointer hover:text-primary' onClick={() => copyText(data.content)} />
      </Tooltip>
      <Tooltip title={isEyeHide ? '显示' : '隐藏'}>
        <EyeIcon className='w-4 h-4 cursor-pointer hover:text-primary' onClick={onEyeChange} />
      </Tooltip>
      <Tooltip title={isNoUse ? '启用上下文' : '禁用上下文'}>
        <MonitorIcon className='w-4 h-4 cursor-pointer hover:text-primary' onClick={onNoUseChange} />
      </Tooltip>
      <Tooltip title='完全删除'>
        <Confirm
          title='确认删除'
          onOk={() => {
            onDelete();
          }}>
          <Trash className='w-4 h-4 cursor-pointer hover:text-primary' />
        </Confirm>
      </Tooltip>
    </div>
  );
};
