/**
 * message type 是 {role: 'user' | 'assistant' | 'system', content: string, hide: boolean, noUse: boolean}
 * @param messages
 * @returns
 */
export const generateTextPrompt = (messages) => {
  const newMessages = [...messages].filter((message) => !message.hide && !message.noUse) as any;
  const lastReverseUserMessageIndex = newMessages.findLastIndex((message) => message.role === 'user');

  const text = newMessages
    .slice(0, lastReverseUserMessageIndex)
    .map((message) => {
      return `----\n${message.role}: \n ${message.content}\n----`;
    })
    .join('\n');
  let prompt = `
你是一个ai对话的助手，请根据用户的问题和用户的历史对话，给出最合适的回答。

用户的问题是：\n
${newMessages[lastReverseUserMessageIndex].content}

用户的历史对话是：
${text} \n
  `;
  return prompt;
};

/**
 * message type 是 {role: 'user' | 'assistant' | 'system', content: string, hide: boolean, noUse: boolean}
 * @param messages
 * @returns
 */
export const generateText = (messages) => {
  const newMessages = [...messages].filter((message) => !message.hide && !message.noUse);

  const text = newMessages
    .map((message) => {
      return '----' + message.role + '\n' + message.content + '\n----';
    })
    .join('\n');

  return text;
};

export const getCodeTemplate = () => {
  return `/**
 * message type 是 {role: 'user' | 'assistant' | 'system', content: string, hide: boolean, noUse: boolean}
 * @param messages
 * @returns
 */
export const generateText = (messages) => {
  const newMessages = [...messages].filter((message) => !message.hide && !message.noUse);

  const text = newMessages
    .map((message) => {
      return '----' + message.role + '\\n' + message.content + '\\n----';
    })
    .join('\\n');

  return text;
};
  `;
};

export const runCode = (code) => {
  // 创建一个Blob对象，包含要执行的代码
  const blob = new Blob([code], { type: 'application/javascript' });

  // 将代码转换为URL
  const codeUrl = URL.createObjectURL(blob);

  try {
    // 使用动态import导入代码
    return import(/* @vite-ignore */ codeUrl)
      .then((module) => {
        // 导入成功后释放URL
        console.log('module', module);
        URL.revokeObjectURL(codeUrl);
        return module;
      })
      .catch((error) => {
        // 发生错误时也释放URL
        URL.revokeObjectURL(codeUrl);
        throw new Error(`代码执行失败: ${error.message}`);
      });
  } catch (error: any) {
    // 捕获任何其他错误
    URL.revokeObjectURL(codeUrl);
    throw new Error(`无法导入代码: ${error.message}`);
  }
};
