'use client';

import * as React from 'react';
import { Check, ChevronsUpDown } from 'lucide-react';

import { cn } from '@/lib/utils';
import { Button } from '@/components/a/button';
import { Command, CommandEmpty, CommandGroup, CommandInput, CommandItem, CommandList } from '@/components/ui/command';
import { Popover, PopoverContent, PopoverTrigger } from '@/components/ui/popover';

type Option = {
  value?: string;
  label: string;
};

type AutoComplateProps = {
  options: Option[];
  placeholder?: string;
  value?: string;
  onChange?: (value: string) => void;
  width?: string;
};
export function AutoComplate(props: AutoComplateProps) {
  const [open, setOpen] = React.useState(false);
  const [value, _setValue] = React.useState('');
  const setValue = (value: string) => {
    props?.onChange?.(value);
    _setValue(value);
  };
  const showLabel = React.useMemo(() => {
    const option = props.options.find((option) => option.value === value);
    if (option) {
      return option?.label;
    }
    if (props.value) return props.value;
    if (value) return value;
    return 'Select ...';
  }, [value, props.value]);
  return (
    <Popover open={open} onOpenChange={setOpen}>
      <PopoverTrigger asChild>
        <Button variant='outline' role='combobox' aria-expanded={open} className={cn(props.width ? props.width : 'w-[400px]', 'justify-between')}>
          {showLabel}
          <ChevronsUpDown className='ml-2 h-4 w-4 shrink-0 opacity-50' />
        </Button>
      </PopoverTrigger>
      <PopoverContent className={cn(props.width ? props.width : 'w-[400px]', ' p-0')}>
        <Command>
          <CommandInput
            placeholder={props.placeholder ?? 'Search options...'}
            onKeyDown={(e: any) => {
              if (e.key === 'Enter') {
                setOpen(false);
                const value = e.target?.value || '';
                setValue(value.trim());
              }
            }}
          />
          <CommandList>
            <CommandEmpty>No options found.</CommandEmpty>
            <CommandGroup>
              {props.options.map((framework) => (
                <CommandItem
                  key={framework.value}
                  value={framework.value}
                  onSelect={(currentValue) => {
                    setValue(currentValue === value ? '' : currentValue);
                    setOpen(false);
                  }}>
                  <Check className={cn('mr-2 h-4 w-4', value === framework.value ? 'opacity-100' : 'opacity-0')} />
                  {framework.label}
                </CommandItem>
              ))}
            </CommandGroup>
          </CommandList>
        </Command>
      </PopoverContent>
    </Popover>
  );
}
