import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
  AlertDialogTrigger,
} from '@/components/ui/alert-dialog';
import { useEffect, useMemo, useState } from 'react';

type useConfirmOptions = {
  confrimProps: ConfirmProps;
};
type Fn = (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
export const useConfirm = (opts?: useConfirmOptions) => {
  const [open, setOpen] = useState(false);
  type ConfirmOptions = {
    onOk?: Fn;
    onCancel?: Fn;
  };
  const confirm = (opts?: ConfirmOptions) => {
    setOpen(true);
  };
  const module = useMemo(() => {
    return <Confirm {...opts?.confrimProps} hasTrigger={false} open={open} setOpen={setOpen} />;
  }, [open]);
  return {
    module: module,
    open,
    setOpen,
    confirm,
  };
};

type ConfirmProps = {
  children?: React.ReactNode;
  tip?: React.ReactNode;
  title?: string;
  description?: string;
  onOkText?: string;
  onCancelText?: string;
  onOk?: Fn;
  onCancle?: Fn;
  hasTrigger?: boolean;
  open?: boolean;
  setOpen?: (open: boolean) => void;
  footer?: React.ReactNode;
};
export const Confirm = (props: ConfirmProps) => {
  const [isOpen, setIsOpen] = useState(props.open);
  const hasTrigger = props.hasTrigger ?? true;
  useEffect(() => {
    setIsOpen(props.open);
  }, [props.open]);
  return (
    <AlertDialog
      open={isOpen}
      onOpenChange={(v) => {
        setIsOpen(v);
        props?.setOpen?.(v);
      }}>
      {hasTrigger && (
        <>
          {props?.children && <AlertDialogTrigger asChild>{props?.children ?? props?.tip ?? '提示'}</AlertDialogTrigger>}
          {!props?.children && <AlertDialogTrigger>{props?.tip ?? '提示'}</AlertDialogTrigger>}
        </>
      )}
      <AlertDialogContent>
        <AlertDialogHeader>
          <AlertDialogTitle>{props?.title ?? '是否确认删除?'}</AlertDialogTitle>
          <AlertDialogDescription>{props?.description ?? '此操作无法撤销，是否继续。'}</AlertDialogDescription>
        </AlertDialogHeader>
        <AlertDialogFooter>
          {props?.footer && <div className='flex gap-2'>{props?.footer}</div>}
          {!props?.footer && (
            <>
              <AlertDialogCancel
                className='cursor-pointer'
                onClick={(e) => {
                  props?.onCancle?.(e);
                  e.stopPropagation();
                }}>
                {props?.onCancelText ?? '取消'}
              </AlertDialogCancel>
              <AlertDialogAction
                className='cursor-pointer'
                onClick={(e) => {
                  props?.onOk?.(e);
                  e.stopPropagation();
                }}>
                {props?.onOkText ?? '确定'}
              </AlertDialogAction>
            </>
          )}
        </AlertDialogFooter>
      </AlertDialogContent>
    </AlertDialog>
  );
};
